@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Namespace.pm 101877 2009-03-07T05:37:41.706351Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Namespace.pm 103851 2009-04-14T06:21:48.827415Z daisuke  $
 
 package Data::Localize::Namespace;
 use Any::Moose;
@@ -41,8 +41,9 @@ sub register {
 
 our %LOADED;
 sub lexicon_get {
-    my ($self, $lang) = @_;
+    my ($self, $lang, $id) = @_;
 
+    $lang =~ s/-/_/g;
     foreach my $namespace ($self->namespaces) {
         my $klass = "$namespace\::$lang";
         if (&Data::Localize::DEBUG) {
@@ -63,8 +64,12 @@ sub lexicon_get {
                     print STDERR "[Data::Localize::Namespace]: lexicon_get - loading $klass\n";
                 }
 
-                my $code = "\n#line " . __LINE__ . ' "' . __FILE__ . "\"\nrequire $klass";
-                eval $code;
+                my $code = 
+                    "\n" .
+                    "#line " . __LINE__ . ' "' . __FILE__ . '"' . "\n" .
+                    "require $klass;"
+                ;
+                eval($code);
                 if ($@) {
                     if (&Data::Localize::DEBUG) {
                         print STDERR "[Data::Localize::Namespace]: lexicon_get - Failed to load $klass: $@\n";
@@ -97,7 +102,7 @@ sub lexicon_get {
             %$h = ();
             %$h = %t;
         }
-        return $h;
+        return $h->{$id};
         
     }
     return ();
